##  Where Can I View and Access My Personal Data?
For more information, see [Users Overview](https://help.sap.com/docs/leanix/ea/users-overview?locale=en-US&state=PRODUCTION&version=CLOUD "View workspace users and manage their access permissions and roles.").
